X-Git-Url: https://git.saurik.com/bison.git/blobdiff_plain/12e3584054c16ab255672c07af0ffc7bb220e8bc..9b33de72cd2469bedac2b5f0a48a8782571ea9db:/src/symlist.h
diff --git a/src/symlist.h b/src/symlist.h
index 9da8afe5..ab9a4b5e 100644
--- a/src/symlist.h
+++ b/src/symlist.h
@@ -1,6 +1,6 @@
/* Lists of symbols for Bison
- Copyright (C) 2002, 2005, 2006 Free Software Foundation, Inc.
+ Copyright (C) 2002, 2005, 2006, 2007 Free Software Foundation, Inc.
This file is part of Bison, the GNU Compiler Compiler.
@@ -23,6 +23,7 @@
# define SYMLIST_H_
# include "location.h"
+# include "scan-code.h"
# include "symtab.h"
/* A list of symbols, used during the parsing to store the rules. */
@@ -30,16 +31,21 @@ typedef struct symbol_list
{
/**
* Whether this node contains a symbol, a semantic type, a \c <*>, or a
- * \c .
+ * \c <>.
*/
enum {
SYMLIST_SYMBOL, SYMLIST_TYPE,
SYMLIST_DEFAULT_TAGGED, SYMLIST_DEFAULT_TAGLESS
} content_type;
union {
- /** The symbol or \c NULL iff node_type = SYMLIST_SYMBOL. */
+ /**
+ * The symbol or \c NULL iff
+ * symbol_list::content_type = SYMLIST_SYMBOL.
+ */
symbol *sym;
- /** The semantic type iff node_type = SYMLIST_TYPE. */
+ /**
+ * The semantic type iff symbol_list::content_type = SYMLIST_TYPE.
+ */
uniqstr type_name;
} content;
location location;
@@ -55,12 +61,9 @@ typedef struct symbol_list
struct symbol_list *midrule_parent_rule;
int midrule_parent_rhs_index;
- /* The action is attached to the LHS of a rule. */
- const char *action;
- location action_location;
-
- /* Whether this symbol's value is used in the current action. */
- bool used;
+ /* The action is attached to the LHS of a rule, but action properties for
+ * each RHS are also stored here. */
+ code_props action_props;
/* Precedence/associativity. */
symbol *ruleprec;
@@ -81,7 +84,7 @@ symbol_list *symbol_list_type_new (uniqstr type_name, location loc);
/** Create a list containing a \c <*> at \c loc. */
symbol_list *symbol_list_default_tagged_new (location loc);
-/** Create a list containing a \c at \c loc. */
+/** Create a list containing a \c <> at \c loc. */
symbol_list *symbol_list_default_tagless_new (location loc);
/** Print this list.
@@ -106,15 +109,12 @@ symbol_list *symbol_list_n_get (symbol_list *l, int n);
symbol N in rule RULE. */
uniqstr symbol_list_n_type_name_get (symbol_list *l, location loc, int n);
-/** The item \c n in symbol list \c l is \c used. */
-void symbol_list_n_used_set (symbol_list *l, int n, bool used);
-
-/** Set the \c \%destructor for \c node as \c destructor at \c loc. */
-void symbol_list_destructor_set (symbol_list *node, const char *destructor,
+/** Set the \c \%destructor for \c node as \c code at \c loc. */
+void symbol_list_destructor_set (symbol_list *node, char const *code,
location loc);
-/** Set the \c \%printer for \c node as \c printer at \c loc. */
-void symbol_list_printer_set (symbol_list *node, const char *printer,
+/** Set the \c \%printer for \c node as \c code at \c loc. */
+void symbol_list_printer_set (symbol_list *node, char const *code,
location loc);
#endif /* !SYMLIST_H_ */